@@ -154,7 +154,8 @@ class ApiResourceFnTyping(NamedTuple):
             return kwargs, errors
         body = self._get_body()
         try:
-            kwargs['body'] = [set_model(self.body_typing, fields) for fields in _body_list(body)] if self.request_body_many else set_model(self.body_typing, body)  # type: ignore
+            expected_typing: Type[BaseModel | List[BaseModel]] = List[self.body_typing] if self.request_body_many else self.body_typing      # type: ignore
+            kwargs['body'] = parse_obj_as(expected_typing, body)
         except ValidationError as ve:
             if self.has_body_validation_error:
                 kwargs['body_validation_error'] = ve
