@@ -9,6 +9,7 @@ from ul_py_tool.commands.cmd import Cmd
 from ul_api_utils.commands.cmd_enc_keys import CmdEncKeys
 from ul_api_utils.commands.cmd_gen_new_api_user import CmdGenerateNewApiUser
 from ul_api_utils.commands.cmd_gen_api_user_token import CmdGenerateApiUserToken
+from ul_api_utils.commands.cmd_generate_api_docs import CmdGenApiFunctionDocumentation
 
 from ul_api_utils.commands.cmd_start import CmdStart
 
@@ -20,6 +21,7 @@ def main() -> None:
         'start_worker': CmdWorkerStart,
         'gen_new_api_user': CmdGenerateNewApiUser,
         'gen_api_user_token': CmdGenerateApiUserToken,
+        'gen_api_docs': CmdGenApiFunctionDocumentation,
     })
 
 
